@@ -73,6 +73,7 @@ KEYTYPE_MOVERESIZE,
 KEYTYPE_POINTERCONTROL,
 KEYTYPE_BRANCHHYPERTEXT,
 KEYTYPE_BRANCHTEXT,
+KEYTYPE_HTMLACTION,
 KEYTYPE_HYPERLINK,
 KEYTYPE_VALUATOR,
 KEYTYPE_HELP,
@@ -114,7 +115,9 @@ KEYSTYLE_SETTINGS,
 KEYSTYLE_SPELL,
 KEYSTYLE_WORDCOMPLETE,
 KEYSTYLE_POINTERCONTROL,
+KEYSTYLE_BRANCHHYPERTEXT,
 KEYSTYLE_BRANCHMODAL,
+KEYSTYLE_HTMLACTION,
 KEYSTYLE_HYPERLINK,
 KEYSTYLE_BRANCHTEXT,
 KEYSTYLE_HELP,
@@ -132,6 +135,7 @@ KEYSTYLE_INSENSITIVE
 #define FONT_SIZE_GROUP_UNIQUE -1
 #define FONT_SIZE_GROUP_WORDCOMPLETE -2
 #define FONT_SIZE_GROUP_GLYPH -3
+#define FONT_SIZE_GROUP_CONTENT -4
 
 #define GOK_MODMASK_CURRENT -1
 #define GOK_MIN_FONT_SIZE 6000 
