@@ -3,8 +3,8 @@
 *
 * Main file for the mighty GOK
 *
-* Copyright 2001,2002 Sun Microsystems, Inc.,
-* Copyright 2001,2002 University Of Toronto
+* Copyright 2001 - 2004 Sun Microsystems, Inc.,
+* Copyright 2001 - 2004 University Of Toronto
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -28,6 +28,7 @@
 
 #include <sys/types.h>
 #include <dirent.h>
+#include <signal.h>
 #include <gnome.h>
 #include <cspi/spi.h>
 #include <libbonobo.h>
@@ -60,8 +61,9 @@
 #include "gok-feedback.h"
 #include "gok-modifier.h"
 #include "gok-action.h"
-#include <signal.h>
 #include "gok-bounds.h"
+#include "gok-keyslotter.h"
+#include "gok-gconf.h"
 
 #define USE_GCONF 1
 
@@ -1479,10 +1481,12 @@ gok_main_display_scan (GokKeyboard* pKeyboard, gchar* nameKeyboard, KeyboardType
 	
 	if (pKeyboard != NULL)
 	{
+	        gok_log ("displaying %s\n", pKeyboard->Name);
 		pKB = pKeyboard;
 	}
 	else
 	{
+	        gok_log ("displaying %s\n", nameKeyboard);
 		pKB = gok_main_keyboard_find_byname (nameKeyboard);
 	}
 
@@ -2090,7 +2094,7 @@ gok_main_initialize_wordcomplete ()
 
     if ( !(gok_wordcomplete_open (gok_wordcomplete_get_default (),
 				  directory_name)) ||
-	 ! (gok_keyslotter_on (gok_wordcomplete_get_default (), KEYTYPE_WORDCOMPLETE))) {
+	 ! (gok_keyslotter_on (TRUE, KEYTYPE_WORDCOMPLETE))) {
 	    gok_log_x ("Error initializing word completion");
 	    
     }
@@ -2186,7 +2190,6 @@ void gok_main_resize_window (GtkWidget* pWindow, GokKeyboard *pKeyboard, gint Wi
 	
 	/* let the keyboard know that the resize was caused by us */
 	gok_keyboard_set_ignore_resize (TRUE);
-
 	
 	/* calculate the upper left corner of the window */
 	switch (gok_data_get_dock_type () ) { /* if we're a dock */
@@ -2281,9 +2284,9 @@ void gok_main_resize_window (GtkWidget* pWindow, GokKeyboard *pKeyboard, gint Wi
 	if (gok_data_get_dock_type () != GOK_DOCK_NONE) {
 		/* if this is a "never expand" keyboard, unset struts! */
 		if (pKeyboard && (pKeyboard->expand == GOK_EXPAND_NEVER))
-			gok_main_update_struts (Width, 1);
+			gok_main_update_struts (Width, 1, left, top);
 		else
-			gok_main_update_struts (Width, Height);
+			gok_main_update_struts (Width, Height, left, top);
 	}
 
 	/* store these values */
@@ -2344,7 +2347,7 @@ enum {
  * TODO: GtkDoc this!
  */
 void
-gok_main_update_struts (gint width, gint height)
+gok_main_update_struts (gint width, gint height, gint x, gint y)
 {
 	GtkWidget *widget = gok_main_get_main_window ();
 	Atom atom_strut = gdk_x11_get_xatom_by_name ("_NET_WM_STRUT");
@@ -2354,13 +2357,13 @@ gok_main_update_struts (gint width, gint height)
 	switch (gok_data_get_dock_type ()) {
 	case GOK_DOCK_TOP:
 		struts[STRUT_TOP] = height;
-		struts[STRUT_TOP_START] = 0;
-		struts[STRUT_TOP_END] = _screen_width - 1;
+		struts[STRUT_TOP_START] = x;
+		struts[STRUT_TOP_END] = width;
 		break;
 	case GOK_DOCK_BOTTOM:
 		struts[STRUT_BOTTOM] = height;
-		struts[STRUT_BOTTOM_START] = 0;
-		struts[STRUT_BOTTOM_END] = _screen_width - 1;
+		struts[STRUT_BOTTOM_START] = x;
+		struts[STRUT_BOTTOM_END] = width;
 		break;
 	default:
 		return;
